Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(349)

Unified Diff: content/renderer/render_frame_proxy.h

Issue 2628133002: When a proxy is detached, immediately delete its associated provisional frame. (Closed)
Patch Set: Charlie's nit Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/renderer/render_frame_impl.cc ('k') | content/renderer/render_frame_proxy.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/render_frame_proxy.h
diff --git a/content/renderer/render_frame_proxy.h b/content/renderer/render_frame_proxy.h
index 3de7d6678e7f0658672a38b73a0a20d3ccaf4e8c..b64b8f130ab20c054a7c418a513bf468049dd186 100644
--- a/content/renderer/render_frame_proxy.h
+++ b/content/renderer/render_frame_proxy.h
@@ -118,6 +118,12 @@ class CONTENT_EXPORT RenderFrameProxy
RenderViewImpl* render_view() { return render_view_; }
blink::WebRemoteFrame* web_frame() { return web_frame_; }
+ void set_provisional_frame_routing_id(int routing_id) {
+ provisional_frame_routing_id_ = routing_id;
+ }
+
+ int provisional_frame_routing_id() { return provisional_frame_routing_id_; }
+
// Returns the widget used for the local frame root.
RenderWidget* render_widget() { return render_widget_; }
@@ -144,7 +150,7 @@ class CONTENT_EXPORT RenderFrameProxy
void OnDidStartLoading();
private:
- RenderFrameProxy(int routing_id, int frame_routing_id);
+ RenderFrameProxy(int routing_id);
void Init(blink::WebRemoteFrame* frame,
RenderViewImpl* render_view,
@@ -179,9 +185,9 @@ class CONTENT_EXPORT RenderFrameProxy
// The routing ID by which this RenderFrameProxy is known.
const int routing_id_;
- // The routing ID of the local RenderFrame (if any) which this
- // RenderFrameProxy is meant to replace in the frame tree.
- const int frame_routing_id_;
+ // The routing ID of the provisional RenderFrame (if any) that is meant to
+ // replace this RenderFrameProxy in the frame tree.
+ int provisional_frame_routing_id_;
// Stores the WebRemoteFrame we are associated with.
blink::WebRemoteFrame* web_frame_;
« no previous file with comments | « content/renderer/render_frame_impl.cc ('k') | content/renderer/render_frame_proxy.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698